@@ -2,10 +2,11 @@ from pathlib import Path
 
 import click
 
-version = "0.4.3"
+version = "0.4.4"
 
-SUBKEY_CATALOG = r"Software\Microsoft\Office\16.0\WEF\TrustedCatalogs"
-SUBKEY_PROVIDER = r"Software\Microsoft\Office\16.0\WEF\Providers"
+SUBKEY_OFFICE = r"Software\Microsoft\Office\16.0"
+OFFICE_SUBKEY_CATALOG = r"WEF\TrustedCatalogs"
+OFFICE_SUBKEY_PROVIDER = r"WEF\Providers"
 APP_NAME = "office-addin-sideloader"
 APP_DIR = Path(click.get_app_dir(APP_NAME))
 MANIFEST_ENCODING = "utf-8"
